==> com.liferay.layout.impl-3.0.7-sources.jar: com/liferay/layout/internal/model/listener/LayoutSetStagingModelListener.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.layout.internal.model.listener;

import com.liferay.portal.kernel.exception.ModelListenerException;
import com.liferay.portal.kernel.model.BaseModelListener;
import com.liferay.portal.kernel.model.LayoutSet;
import com.liferay.portal.kernel.model.ModelListener;
import com.liferay.staging.model.listener.StagingModelListener;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Akos Thurzo
 */
@Component(immediate = true, service = ModelListener.class)
public class LayoutSetStagingModelListener
	extends BaseModelListener<LayoutSet> {

	@Override
	public void onAfterCreate(LayoutSet layoutSet)
		throws ModelListenerException {

		_stagingModelListener.onAfterCreate(layoutSet);
	}

	@Override
	public void onAfterRemove(LayoutSet layoutSet)
		throws ModelListenerException {

		_stagingModelListener.onAfterRemove(layoutSet);
	}

	@Override
	public void onAfterUpdate(LayoutSet layoutSet)
		throws ModelListenerException {

		_stagingModelListener.onAfterUpdate(layoutSet);
	}

	@Reference
	private StagingModelListener<LayoutSet> _stagingModelListener;

}

==> com.liferay.layout.impl-6.0.20-sources.jar: com/liferay/layout/internal/model/listener/LayoutSetStagingModelListener.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.layout.internal.model.listener;

import com.liferay.portal.kernel.exception.ModelListenerException;
import com.liferay.portal.kernel.model.BaseModelListener;
import com.liferay.portal.kernel.model.LayoutSet;
import com.liferay.portal.kernel.model.ModelListener;
import com.liferay.staging.model.listener.StagingModelListener;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Akos Thurzo
 */
@Component(immediate = true, service = ModelListener.class)
public class LayoutSetStagingModelListener
	extends BaseModelListener<LayoutSet> {

	@Override
	public void onAfterCreate(LayoutSet layoutSet)
		throws ModelListenerException {

		_stagingModelListener.onAfterCreate(layoutSet);
	}

	@Override
	public void onAfterRemove(LayoutSet layoutSet)
		throws ModelListenerException {

		_stagingModelListener.onAfterRemove(layoutSet);
	}

	@Override
	public void onAfterUpdate(LayoutSet originalLayoutSet, LayoutSet layoutSet)
		throws ModelListenerException {

		_stagingModelListener.onAfterUpdate(layoutSet);
	}

	@Reference
	private StagingModelListener<LayoutSet> _stagingModelListener;

}
